@@ -51,15 +51,17 @@ class SentenceTransformer(nn.Sequential):
                 model_url = model_path
                 folder_name = model_url.replace("https://", "").replace("http://", "").replace("/", "_")[:250].rstrip('.zip')
 
-                try:
-                    from torch.hub import _get_torch_home
-                    torch_cache_home = _get_torch_home()
-                except ImportError:
-                    torch_cache_home = os.path.expanduser(
-                        os.getenv('TORCH_HOME', os.path.join(
-                            os.getenv('XDG_CACHE_HOME', '~/.cache'), 'torch')))
-                default_cache_path = os.path.join(torch_cache_home, 'sentence_transformers')
-                model_path = os.path.join(default_cache_path, folder_name)
+                cache_folder = os.getenv('SENTENCE_TRANSFORMERS_HOME')
+                if cache_folder is None:
+                    try:
+                        from torch.hub import _get_torch_home
+                        torch_cache_home = _get_torch_home()
+                    except ImportError:
+                        torch_cache_home = os.path.expanduser(os.getenv('TORCH_HOME', os.path.join(os.getenv('XDG_CACHE_HOME', '~/.cache'), 'torch')))
+
+                    cache_folder = os.path.join(torch_cache_home, 'sentence_transformers')
+
+                model_path = os.path.join(cache_folder, folder_name)
 
                 if not os.path.exists(model_path) or not os.listdir(model_path):
                     if model_url[-1] == "/":
@@ -92,8 +94,6 @@ class SentenceTransformer(nn.Sequential):
                         raise e
 
 
-
-
             #### Load from disk
             if model_path is not None:
                 logging.info("Load SentenceTransformer from folder: {}".format(model_path))
@@ -136,6 +136,7 @@ class SentenceTransformer(nn.Sequential):
                num_workers: int = 0) -> Union[List[Tensor], ndarray, Tensor]:
         """
         Computes sentence embeddings
+
         :param sentences: the sentences to embed
         :param batch_size: the batch size used for the computation
         :param show_progress_bar: Output a progress bar when encode sentences
